@@ -11,8 +11,9 @@ use base qw(App::Followme::Module);
 use Cwd;
 use IO::File;
 use File::Spec::Functions qw(splitdir catfile);
+use App::Followme::FIO;
 
-our $VERSION = "1.16";
+our $VERSION = "1.90";
 
 #----------------------------------------------------------------------
 # Read the default parameter values
@@ -21,7 +22,6 @@ sub parameters {
     my ($pkg) = @_;
 
     return (
-            configuration_file => 'followme.cfg',
            );
 }
 
@@ -35,7 +35,7 @@ sub run {
 
     $self->update_folder($directory,
                          $configuration_files,
-                         %$self);
+                         %{$self->{configuration}});
 
     return;
 }
@@ -78,10 +78,12 @@ sub load_and_run_modules {
     my ($self, $modules, $base_directory, $directory, %configuration) = @_;
 
     $configuration{base_directory} = $base_directory;
+    $configuration{current_directory} = $directory;
+
     foreach my $module (@$modules) {
         eval "require $module" or die "Module not found: $module\n";
 
-        my $object = $module->new(\%configuration);
+        my $object = $module->new(%configuration);
         $object->run($directory);
     }
 
@@ -94,54 +96,20 @@ sub load_and_run_modules {
 sub set_directories {
     my ($self, @configuration_files) = @_;
 
-    my ($directory, $file) = $self->split_filename($configuration_files[0]);
+    my ($directory, $file) = fio_split_filename($configuration_files[0]);
     $self->{base_directory} = $directory;
     $self->{top_directory} = $directory;
     return;
 }
 
 #----------------------------------------------------------------------
-# Update the configuration from a file
+#  Save the configuration for other modules
 
-sub update_configuration {
-    my ($self, $filename, %configuration) = @_;
+sub setup {
+    my ($self, %configuration) = @_;
 
-    my @modules;
-    $configuration{run_before} = [];
-    $configuration{run_after} = [];
-
-    my $fd = IO::File->new($filename, 'r');
-
-    if ($fd) {
-        while (my $line = <$fd>) {
-            # Ignore comments and blank lines
-            next if $line =~ /^\s*\#/ || $line !~ /\S/;
-
-            # Split line into name and value, remove leading and
-            # trailing whitespace
-
-            my ($name, $value) = split (/\s*=\s*/, $line, 2);
-
-            die "Bad line in config file: ($name)" unless defined $value;
-            $value =~ s/\s+$//;
-
-            # Insert the name and value into the hash
-
-            if ($name eq 'run_before' || $name eq 'module') {
-                push(@{$configuration{run_before}}, $value);
-
-            } elsif ($name eq 'run_after') {
-                push(@{$configuration{run_after}}, $value);
-
-            } else {
-                $configuration{$name} = $value;
-            }
-        }
-
-        close($fd);
-    }
-
-    return %configuration;
+    $self->{configuration} = \%configuration;
+    return;
 }
 
 #----------------------------------------------------------------------
@@ -153,18 +121,18 @@ sub update_folder {
     my $configuration_file = shift(@$configuration_files) ||
                              catfile($directory, $self->{configuration_file});
 
-    my ($base_directory, $filename) = $self->split_filename($configuration_file);
+    my ($base_directory, $filename) = fio_split_filename($configuration_file);
 
     my ($run_before, $run_after);
     if (-e $configuration_file) {
-        %configuration = $self->update_configuration($configuration_file,
-                                                     %configuration);
+        %configuration = $self->read_configuration($configuration_file,
+                                                   %configuration);
 
-        $run_before = $configuration{run_before};
-        delete $configuration{run_before};
+        $run_before = $configuration{''}->{run_before};
+        delete $configuration{''}->{run_before};
 
-        $run_after = $configuration{run_after};
-        delete $configuration{run_after};
+        $run_after = $configuration{''}->{run_after};
+        delete $configuration{''}->{run_after};
     }
 
     $self->load_and_run_modules($run_before,
@@ -179,7 +147,7 @@ sub update_folder {
                              %configuration);
 
     } elsif (! $self->{quick_update}) {
-        my ($filenames, $directories) = $self->visit($directory);
+        my ($filenames, $directories) = fio_visit($directory);
 
         foreach my $subdirectory (@$directories) {
             $self->update_folder($subdirectory,
