@@ -5,17 +5,17 @@ use strict;
 use warnings;
 
 use Cwd;
-our $VERSION = "1.16";
+our $VERSION = "1.90";
 
 #----------------------------------------------------------------------
 # Create object that returns files in a directory tree
 
 sub new {
-    my ($pkg, $configuration) = @_;
+    my ($pkg, %configuration) = @_;
 
     my $self = {};
     my $cycle = {};
-    initialize($pkg, $configuration, $self, $cycle);
+    initialize($pkg, $self, $cycle, %configuration);
 
     return $self;
 }
@@ -24,7 +24,7 @@ sub new {
 # Read the default parameter values
 
 sub parameters {
-    my ($self) = @_;
+    my ($pkg) = @_;
 
     return (
             quick_update => 0,
@@ -34,57 +34,103 @@ sub parameters {
 }
 
 #----------------------------------------------------------------------
-# Run the object on a directory (stub)
+# Update an object's fields from all the configuration hashes
 
-sub run {
-    my ($self, $directory) = @_;
-    die "Run method not defined";
+sub add_configurations {
+    my ($self, $pkg, %configuration) = @_;
+
+    foreach my $field ($self->all_fields($configuration{''})) {
+        $self->{$field} = $configuration{''}->{$field};
+    }
+
+    foreach my $field ($self->all_fields($configuration{$pkg})) {
+        $self->{$field} = $configuration{$pkg}->{$field};
+    }
+
+    foreach my $field ($self->all_fields(\%configuration)) {
+        $self->{$field} = $configuration{$field};
+    }
+
+    return;
+}
+
+#----------------------------------------------------------------------
+# Create subobjects for any parameter ending in _pkg
+
+sub add_subpackages {
+    my ($self, %configuration) = @_;
+
+    foreach my $field ($self->all_fields($self)) {
+        my $subpkg = $self->{$field};
+        next unless $field =~ s/_pkg$//;
+
+        eval "require $subpkg" or die "Module not found: $subpkg\n";
+
+        if ($subpkg->isa('App::Followme::ConfiguredObject')) {
+            $self->{$field} = $subpkg->new(%configuration);
+        } elsif ($subpkg->can('new')) {
+            $self->{$field} = $subpkg->new();
+        } else {
+            $self->{$field} = $subpkg;
+        }
+    }
+
+    return;
+}
+
+#----------------------------------------------------------------------
+# Get the configuration fields that apply to this package
+
+sub all_fields {
+    my ($self, $configuration) = @_;
+
+    my @fields = ();
+    if (defined $configuration) {
+        my $pkg = ref $self;
+        my %parameters = $pkg->parameters();
+
+        foreach my $field (keys %$configuration) {
+            next if ref $configuration->{$field};
+            next unless exists $parameters{$field};
+
+            push(@fields, $field);
+        }
+    }
+
+    return @fields;
 }
 
 #----------------------------------------------------------------------
 # Initialize the object by populating its hash
 
 sub initialize {
-    my ($pkg, $configuration, $self, $cycle) = @_;
+    my ($pkg, $self, $cycle, %configuration) = @_;
+    %configuration = () unless %configuration;
     return if $cycle->{$pkg};
 
     no strict 'refs';
-    initialize($_, $configuration, $self, $cycle) foreach @{"${pkg}::ISA"};
+    initialize($_, $self, $cycle, %configuration) foreach @{"${pkg}::ISA"};
     $cycle->{$pkg} = 1;
 
-    $self = bless($self, $pkg);
+    my %parameters = $pkg->parameters();
+    while (my ($key, $value) = each(%parameters)) {
+        $self->{$key} = $value if length $value;
+    }
 
-    $self->update_parameters($configuration)
-        if defined &{"${pkg}::parameters"};
+     $self = bless($self, $pkg);
 
-    $self->setup($configuration)
-        if defined &{"${pkg}::setup"};
+    $self->add_configurations($pkg, %configuration);
+    $self->add_subpackages(%configuration);
 
+    $self->setup(%configuration) if defined &{"${pkg}::setup"};
     return;
 }
+
 #----------------------------------------------------------------------
 # Set up object fields (stub)
 
 sub setup {
-    my ($self, $configuration) = @_;
-    return;
-}
-
-#----------------------------------------------------------------------
-# Update a module's parameters
-
-sub update_parameters {
-    my ($self, $configuration) = @_;
-
-    my %parameters = $self->parameters();
-    foreach my $field (keys %parameters) {
-        if (exists $configuration->{$field}) {
-            $self->{$field} = $configuration->{$field};
-        } else {
-            $self->{$field} = $parameters{$field};
-        }
-    }
-
+    my ($self, %configuration) = @_;
     return;
 }
 
@@ -115,18 +161,18 @@ parameters from the configuration file.
 Create a new object from the configuration. The configuration is a reference to
 a hash containing fields with the same names as the object parameters. Fields
 in the configuration whose name does not match an object parameter are ignored.
+If a configuration field ends in "_pkg", its value is assumed to be the name of
+a subpackage, which is is created and stored in a field whose name is stripped
+of the "_pkg" suffix.
 
 =item %parameters = $self->parameters();
 
 Returns a hash of the default values of the object's parameters.
 
-=item $self->run($directory);
+=item $self->setup(%configuration);
 
-Run the object on the files in a directory.
-
-=item $self->setup($configuration);
-
-Sets computed parameters of the object.
+Sets those parameters of the object which are computed when the object is
+initialized.
 
 =back
 
