@@ -6,20 +6,23 @@ use warnings;
 
 use lib '../..';
 
-use File::Spec::Functions qw(catfile);
 use base qw(App::Followme::Module);
 
-our $VERSION = "1.16";
+use File::Spec::Functions qw(catfile);
+use App::Followme::FIO;
+
+our $VERSION = "1.90";
 
 #----------------------------------------------------------------------
 # Read the default parameter values
 
 sub parameters {
-    my ($self) = @_;
+    my ($pkg) = @_;
 
     return (
-            site_url => '',
+            remote_url => '',
             sitemap => 'sitemap.txt',
+            data_pkg => 'App::Followme::WebData',
            );
 }
 
@@ -27,13 +30,13 @@ sub parameters {
 # Write a list of urls in a directory tree
 
 sub run {
-    my ($self, $directory) = @_;
+    my ($self, $folder) = @_;
 
-    my @urls = $self->list_urls($directory);
+    my @urls = $self->list_urls($folder);
     my $page = join("\n", @urls) . "\n";
 
-    my $filename = catfile($directory, $self->{sitemap});
-    $self->write_page($filename, $page);
+    my $filename = catfile($folder, $self->{sitemap});
+    fio_write_page($filename, $page);
 
     return;
 }
@@ -42,23 +45,23 @@ sub run {
 # Return a list of the urls of all web pages in a directory
 
 sub list_urls {
-    my ($self, $directory) = @_;
+    my ($self, $folder) = @_;
 
     my @urls;
-    my $data = {};
-    my ($filenames, $directories) =  $self->visit($directory);
+    my $index_file = $self->to_file($folder);
+    my $files = $self->{data}->build('files', $index_file);
 
-    foreach my $filename (@$filenames) {
-        next unless $self->match_file($filename);
-
-        $data = $self->build_url($data, $directory, $filename);
-        my $url = $self->{site_url} . $data->{absolute_url};
-        push(@urls, $url);
+    foreach my $file (@$files) {
+        # build returns a reference, so must dereference
+        my $url = $self->{data}->build('absolute_url', $file);
+        my $page_url = $self->{remote_url} . $$url;
+        push(@urls, $page_url);
     }
 
-    foreach my $subdirectory (@$directories) {
-        next unless $self->search_directory($directory);
-        push(@urls, $self->list_urls($subdirectory));
+    my $folders = $self->{data}->build('folders', $index_file);
+
+    foreach my $subfolder (@$folders) {
+        push(@urls, $self->list_urls($subfolder));
     }
 
     return @urls;
@@ -68,10 +71,10 @@ sub list_urls {
 # Clean up parameters passed to this object
 
 sub setup {
-    my ($self, $configuration) = @_;
+    my ($self, %configuration) = @_;
 
     # Remove any trailing slash
-    $self->{site_url} =~ s/\/$//;
+    $self->{remote_url} =~ s/\/$//;
     return;
 }
 
@@ -88,7 +91,7 @@ App::Followme::CreateSitemap - Create a Google sitemap
 
     use App::Followme::Sitemap;
     my $map = App::Followme::Sitemap->new();
-    $map->run($directory);
+    $map->run($folder);
 
 =head1 DESCRIPTION
 
@@ -108,10 +111,15 @@ The name of the sitemap file. It is written to the directory this module is
 invoked from. Typically this is the top folder of a site. The default value is
 sitemap.txt.
 
-=item site_url
+=item remote_url
 
 The url of the website, e.g. http://www.example.com.
 
+=item data_pkg
+
+The package used to retrieve information from each file contained in the
+sitemap. The default value is 'App::Followme::WebData'.
+
 =back
 
 =head1 LICENSE
